"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MSG_UUID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MSB_FIELD_NUMBER: builtins.int
    LSB_FIELD_NUMBER: builtins.int
    msb: builtins.int = ...
    lsb: builtins.int = ...
    def __init__(
        self,
        *,
        msb: builtins.int = ...,
        lsb: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["lsb", b"lsb", "msb", b"msb"]
    ) -> None: ...

global___MSG_UUID = MSG_UUID

class MSG_UUID_AND_VERSION(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MSB_FIELD_NUMBER: builtins.int
    LSB_FIELD_NUMBER: builtins.int
    VER_FIELD_NUMBER: builtins.int
    msb: builtins.int = ...
    lsb: builtins.int = ...
    ver: builtins.int = ...
    def __init__(
        self,
        *,
        msb: builtins.int = ...,
        lsb: builtins.int = ...,
        ver: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "lsb", b"lsb", "msb", b"msb", "ver", b"ver"
        ],
    ) -> None: ...

global___MSG_UUID_AND_VERSION = MSG_UUID_AND_VERSION

class MSG_UUIDs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UUIDS_FIELD_NUMBER: builtins.int
    @property
    def uuids(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MSG_UUID
    ]: ...
    def __init__(
        self,
        *,
        uuids: typing.Optional[typing.Iterable[global___MSG_UUID]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["uuids", b"uuids"]
    ) -> None: ...

global___MSG_UUIDs = MSG_UUIDs

class MSG_OptionalSerial(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRESENT_FIELD_NUMBER: builtins.int
    SERIAL_FIELD_NUMBER: builtins.int
    present: builtins.bool = ...
    serial: builtins.int = ...
    def __init__(
        self,
        *,
        present: builtins.bool = ...,
        serial: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "present", b"present", "serial", b"serial"
        ],
    ) -> None: ...

global___MSG_OptionalSerial = MSG_OptionalSerial

class MSG_Notification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _Type(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Type.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        Fact = MSG_Notification.Type.V(0)
        Id = MSG_Notification.Type.V(1)
        Catchup = MSG_Notification.Type.V(2)
        Complete = MSG_Notification.Type.V(3)
        Facts = MSG_Notification.Type.V(4)
    class Type(metaclass=_Type):
        V = typing.NewType("V", builtins.int)
    Fact = MSG_Notification.Type.V(0)
    Id = MSG_Notification.Type.V(1)
    Catchup = MSG_Notification.Type.V(2)
    Complete = MSG_Notification.Type.V(3)
    Facts = MSG_Notification.Type.V(4)

    TYPE_FIELD_NUMBER: builtins.int
    FACT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    FACTS_FIELD_NUMBER: builtins.int
    type: global___MSG_Notification.Type.V = ...
    @property
    def fact(self) -> global___MSG_Fact: ...
    @property
    def id(self) -> global___MSG_UUID: ...
    @property
    def facts(self) -> global___MSG_Facts: ...
    def __init__(
        self,
        *,
        type: global___MSG_Notification.Type.V = ...,
        fact: typing.Optional[global___MSG_Fact] = ...,
        id: typing.Optional[global___MSG_UUID] = ...,
        facts: typing.Optional[global___MSG_Facts] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "fact", b"fact", "facts", b"facts", "id", b"id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "fact", b"fact", "facts", b"facts", "id", b"id", "type", b"type"
        ],
    ) -> None: ...

global___MSG_Notification = MSG_Notification

class MSG_SubscriptionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JSON_FIELD_NUMBER: builtins.int
    json: typing.Text = ...
    def __init__(
        self,
        *,
        json: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["json", b"json"]
    ) -> None: ...

global___MSG_SubscriptionRequest = MSG_SubscriptionRequest

class MSG_FactSpecsJson(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JSON_FIELD_NUMBER: builtins.int
    json: typing.Text = ...
    def __init__(
        self,
        *,
        json: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["json", b"json"]
    ) -> None: ...

global___MSG_FactSpecsJson = MSG_FactSpecsJson

class MSG_OptionalFact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRESENT_FIELD_NUMBER: builtins.int
    FACT_FIELD_NUMBER: builtins.int
    present: builtins.bool = ...
    @property
    def fact(self) -> global___MSG_Fact: ...
    def __init__(
        self,
        *,
        present: builtins.bool = ...,
        fact: typing.Optional[global___MSG_Fact] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["fact", b"fact"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["fact", b"fact", "present", b"present"],
    ) -> None: ...

global___MSG_OptionalFact = MSG_OptionalFact

class MSG_OptionalUuid(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRESENT_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    present: builtins.bool = ...
    @property
    def uuid(self) -> global___MSG_UUID: ...
    def __init__(
        self,
        *,
        present: builtins.bool = ...,
        uuid: typing.Optional[global___MSG_UUID] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["uuid", b"uuid"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["present", b"present", "uuid", b"uuid"],
    ) -> None: ...

global___MSG_OptionalUuid = MSG_OptionalUuid

class MSG_Fact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    header: typing.Text = ...
    payload: typing.Text = ...
    def __init__(
        self,
        *,
        header: typing.Text = ...,
        payload: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "header", b"header", "payload", b"payload"
        ],
    ) -> None: ...

global___MSG_Fact = MSG_Fact

class MSG_Facts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FACT_FIELD_NUMBER: builtins.int
    @property
    def fact(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MSG_Fact
    ]: ...
    def __init__(
        self,
        *,
        fact: typing.Optional[typing.Iterable[global___MSG_Fact]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["fact", b"fact"]
    ) -> None: ...

global___MSG_Facts = MSG_Facts

class MSG_ConditionalPublishRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FACTS_FIELD_NUMBER: builtins.int
    TOKENPRESENT_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    tokenPresent: builtins.bool = ...
    @property
    def facts(self) -> global___MSG_Facts: ...
    @property
    def token(self) -> global___MSG_UUID: ...
    def __init__(
        self,
        *,
        facts: typing.Optional[global___MSG_Facts] = ...,
        tokenPresent: builtins.bool = ...,
        token: typing.Optional[global___MSG_UUID] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["facts", b"facts", "token", b"token"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "facts", b"facts", "token", b"token", "tokenPresent", b"tokenPresent"
        ],
    ) -> None: ...

global___MSG_ConditionalPublishRequest = MSG_ConditionalPublishRequest

class MSG_ConditionalPublishResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool = ...
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["success", b"success"]
    ) -> None: ...

global___MSG_ConditionalPublishResult = MSG_ConditionalPublishResult

class MSG_Empty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___MSG_Empty = MSG_Empty

class MSG_ServerProtocolVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAJOR_FIELD_NUMBER: builtins.int
    MINOR_FIELD_NUMBER: builtins.int
    PATCH_FIELD_NUMBER: builtins.int
    major: builtins.int = ...
    minor: builtins.int = ...
    patch: builtins.int = ...
    def __init__(
        self,
        *,
        major: builtins.int = ...,
        minor: builtins.int = ...,
        patch: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "major", b"major", "minor", b"minor", "patch", b"patch"
        ],
    ) -> None: ...

global___MSG_ServerProtocolVersion = MSG_ServerProtocolVersion

class MSG_ServerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class PropertyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        value: typing.Text = ...
        def __init__(
            self,
            *,
            key: typing.Text = ...,
            value: typing.Text = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["key", b"key", "value", b"value"],
        ) -> None: ...
    PROPERTY_FIELD_NUMBER: builtins.int
    @property
    def property(
        self,
    ) -> google.protobuf.internal.containers.ScalarMap[typing.Text, typing.Text]: ...
    def __init__(
        self,
        *,
        property: typing.Optional[typing.Mapping[typing.Text, typing.Text]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["property", b"property"]
    ) -> None: ...

global___MSG_ServerProperties = MSG_ServerProperties

class MSG_ServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VERSION_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def version(self) -> global___MSG_ServerProtocolVersion: ...
    @property
    def properties(self) -> global___MSG_ServerProperties: ...
    def __init__(
        self,
        *,
        version: typing.Optional[global___MSG_ServerProtocolVersion] = ...,
        properties: typing.Optional[global___MSG_ServerProperties] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "properties", b"properties", "version", b"version"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "properties", b"properties", "version", b"version"
        ],
    ) -> None: ...

global___MSG_ServerConfig = MSG_ServerConfig

class MSG_StringSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EMBEDDEDSTRING_FIELD_NUMBER: builtins.int
    embeddedString: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    def __init__(
        self,
        *,
        embeddedString: typing.Optional[typing.Iterable[typing.Text]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["embeddedString", b"embeddedString"]
    ) -> None: ...

global___MSG_StringSet = MSG_StringSet

class MSG_String(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EMBEDDEDSTRING_FIELD_NUMBER: builtins.int
    embeddedString: typing.Text = ...
    def __init__(
        self,
        *,
        embeddedString: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["embeddedString", b"embeddedString"]
    ) -> None: ...

global___MSG_String = MSG_String

class MSG_StateForRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NSPRESENT_FIELD_NUMBER: builtins.int
    NS_FIELD_NUMBER: builtins.int
    AGGIDS_FIELD_NUMBER: builtins.int
    nsPresent: builtins.bool = ...
    ns: typing.Text = ...
    @property
    def aggIds(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MSG_UUID
    ]: ...
    def __init__(
        self,
        *,
        nsPresent: builtins.bool = ...,
        ns: typing.Text = ...,
        aggIds: typing.Optional[typing.Iterable[global___MSG_UUID]] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "aggIds", b"aggIds", "ns", b"ns", "nsPresent", b"nsPresent"
        ],
    ) -> None: ...

global___MSG_StateForRequest = MSG_StateForRequest

class MSG_CurrentDatabaseTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MILLIS_FIELD_NUMBER: builtins.int
    millis: builtins.int = ...
    def __init__(
        self,
        *,
        millis: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["millis", b"millis"]
    ) -> None: ...

global___MSG_CurrentDatabaseTime = MSG_CurrentDatabaseTime

class MSG_SnapshotId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    key: typing.Text = ...
    @property
    def uuid(self) -> global___MSG_OptionalUuid: ...
    def __init__(
        self,
        *,
        key: typing.Text = ...,
        uuid: typing.Optional[global___MSG_OptionalUuid] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["uuid", b"uuid"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["key", b"key", "uuid", b"uuid"]
    ) -> None: ...

global___MSG_SnapshotId = MSG_SnapshotId

class MSG_Snapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    FACTID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    COMPRESSED_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    compressed: builtins.bool = ...
    @property
    def id(self) -> global___MSG_SnapshotId: ...
    @property
    def factId(self) -> global___MSG_UUID: ...
    def __init__(
        self,
        *,
        id: typing.Optional[global___MSG_SnapshotId] = ...,
        factId: typing.Optional[global___MSG_UUID] = ...,
        data: builtins.bytes = ...,
        compressed: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["factId", b"factId", "id", b"id"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "compressed",
            b"compressed",
            "data",
            b"data",
            "factId",
            b"factId",
            "id",
            b"id",
        ],
    ) -> None: ...

global___MSG_Snapshot = MSG_Snapshot

class MSG_OptionalSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRESENT_FIELD_NUMBER: builtins.int
    SNAPSHOT_FIELD_NUMBER: builtins.int
    present: builtins.bool = ...
    @property
    def snapshot(self) -> global___MSG_Snapshot: ...
    def __init__(
        self,
        *,
        present: builtins.bool = ...,
        snapshot: typing.Optional[global___MSG_Snapshot] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["snapshot", b"snapshot"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "present", b"present", "snapshot", b"snapshot"
        ],
    ) -> None: ...

global___MSG_OptionalSnapshot = MSG_OptionalSnapshot
